@@ -56,11 +56,13 @@ def predict() -> Response:
     #if flask.request.content_type == 'text/csv':
     if flask.request.content_type == 'application/gzip':
         logger.info('[PREDICT] Reading input data.')
-        predict_data = flask.request.data.decode('utf-8')
+        #predict_data = flask.request.data.decode('utf-8')
+        #logger.info(f'[PREDICT] Loading input data {flask.request.data}')
+        predict_data = flask.request.data
         buffer = StringIO()
         buffer.write(predict_data)
         buffer.seek(0)
-        predict_input = pd.read_csv(buffer, sep='|', quotechar='"')
+        predict_input = pd.read_csv(buffer, compression='gzip', sep='|', quotechar='"')
     else:
         return flask.Response(response='This predictor only supports CSV data', status=415,
                               mimetype='text/plain')
