@@ -53,11 +53,18 @@ class SbModel:
         transformed_input = self.input_prep.transform(predict_input)
         return self.model.predict(transformed_input)
 
+    def get_query_from_template(self, template_path, params):
+        with open(template_path, 'rt') as fr:
+            query_template = fr.read()
+        return query_template.format(**params)
+
     def input_data_list(self):
-        model_input_data_query = MODEL_INPUT_DATA_TEMPLATE_QUERY.format(MODEL_NAME=self.model_name).format(**self.query_dict)
-        predict_input_data_query = PREDICT_INPUT_DATA_TEMPLATE_QUERY.format(MODEL_NAME=self.model_name).format(**self.query_dict)
-        model_input_dict = {'query': model_input_data_query, 'bucket': self.bucket, 'path': self.input_train_path}
-        predict_input_dict = {'query': predict_input_data_query, 'bucket': self.bucket, 'path': self.input_predict_path}
+        model_input_data_query = MODEL_INPUT_DATA_TEMPLATE_QUERY.format(MODEL_NAME=self.model_name)
+        predict_input_data_query = PREDICT_INPUT_DATA_TEMPLATE_QUERY.format(MODEL_NAME=self.model_name)
+        model_input_dict = {'query': self.get_query_from_template(model_input_data_query, self.query_dict),
+                            'bucket': self.bucket, 'path': self.input_train_path}
+        predict_input_dict = {'query': self.get_query_from_template(predict_input_data_query, self.query_dict),
+                              'bucket': self.bucket, 'path': self.input_predict_path}
         return [model_input_dict, predict_input_dict]
 
     def batch_transform_job(self):
